import sys, os
import unittest
os.environ["TF_NUM_INTEROP_THREADS"] = "8"
os.environ["TF_NUM_INTRAOP_THREADS"] = "8"
os.environ["ITK_GLOBAL_DEFAULT_NUMBER_OF_THREADS"] = "8"
import tempfile
import shutil
import antspyt1w
import antspynet
import ants
import math
import re
import pandas as pd
# just test that things loaded ok
if os.getenv('CI') == 'true' and os.getenv('CIRCLECI') == 'true':
    def test_simple():
        assert os.getenv('CI') == 'true' and os.getenv('CIRCLECI') == 'true'
    def test_download():
        assert antspyt1w.get_data() == None
    def test_img():
        fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
        img = ants.image_read( fn )
        assert img is not None
    def test_inspect():
        with tempfile.TemporaryDirectory() as temp_dir:
            fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
            img = ants.image_read( fn )
            tempfn=temp_dir+'/apt1wtest'
            testhier = antspyt1w.inspect_raw_t1( img, tempfn )
            assert math.fabs(testhier['brain']['resnetGrade'].iloc[0]-1.56) < 0.1
else:
    def test_download():
        assert antspyt1w.get_data() == None
    def test_img():
        fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
        img = ants.image_read( fn )
        assert img is not None
    def test_inspect():
        with tempfile.TemporaryDirectory() as temp_dir:
            fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
            img = ants.image_read( fn )
            tempfn=temp_dir+'/apt1wtest'
            testhier = antspyt1w.inspect_raw_t1( img, tempfn )
            assert math.fabs(testhier['brain']['resnetGrade'].iloc[0]-1.56) < 0.1
    def test_nbm():
        with tempfile.TemporaryDirectory() as temp_dir:
            fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
            img = ants.image_read( fn )
            tempfn=temp_dir+'/apt1wtest'
            braintissuemask = antspyt1w.brain_extraction( img  )
            print("dbf")
            deep_bf = antspyt1w.deep_nbm( img * braintissuemask,
                antspyt1w.get_data("deep_nbm_rank",target_extension='.h5'),
                csfquantile=None, aged_template=True )
            return deep_bf
    def test_deepcit():
        with tempfile.TemporaryDirectory() as temp_dir:
            fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
            img = ants.image_read( fn )
            tempfn=temp_dir+'/apt1wtest'
            braintissuemask = antspyt1w.brain_extraction( img  )
            print("cit")
            deep_bf = antspyt1w.deep_cit168( img * braintissuemask, verbose=True )
            return deep_bf
    def test_hier():
        with tempfile.TemporaryDirectory() as temp_dir:
            fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
            img = ants.image_read( fn )
            tempfn=temp_dir+'/apt1wtest'
            testhier = antspyt1w.hierarchical( img, output_prefix=tempfn, labels_to_register=None, imgbxt=None, cit168=False, is_test=True, verbose=True)
            mmdfw = antspyt1w.merge_hierarchical_csvs_to_wide_format( testhier['dataframes'] )
            return testhier
            # assert math.fabs(testhier['brain_image']['resnetGrade']-1.56) < 0.1


if False:
    import ants
    import antspyt1w
    fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
    img = ants.image_read( fn )
    tempfn='/tmp/apt1wtestA'
    testhier0 = antspyt1w.hierarchical( img, output_prefix=tempfn, labels_to_register=None, imgbxt=None, cit168=False, is_test=True, verbose=True)
    tempfn='/tmp/apt1wtestB'
    testhier1 = antspyt1w.hierarchical( img, output_prefix=tempfn, labels_to_register=None, imgbxt=None, cit168=False, is_test=True, verbose=True)



import antspyt1w
import ants
# localsyn(img, template, hemiS, templateHemi, whichHemi, padder, iterations, output_prefix, total_sigma=0.5)

fn = antspyt1w.get_data('PPMI-3803-20120814-MRI_T1-I340756', target_extension='.nii.gz' )
fn2 = antspyt1w.get_data('28386-00000000-T1w-01', target_extension='.nii.gz' )
img= ants.image_read( fn )
img2= ants.image_read( fn2 )
msk=ants.get_mask(img)
msk2=ants.get_mask(img2)
its=[40,0,0,0]
# reproducibility
#
# region_reg(input_image, input_image_tissue_segmentation, input_image_region_segmentation, input_template, input_template_region_segmentation, output_prefix, padding=10, labels_to_register=[2, 3, 4, 5], total_sigma=0.5, is_test=False)
lsyn0=antspyt1w.region_reg(img, msk, msk, img2, msk2,  padding=8,  output_prefix='/tmp/BB', total_sigma=0.5, is_test=True )
lsyn1=antspyt1w.region_reg(img, msk, msk, img2, msk2,  padding=8,  output_prefix='/tmp/CC', total_sigma=0.5, is_test=True )
# lsyn0=antspyt1w.localsyn(img, img2, msk, msk2, whichHemi=1, padder=0, iterations=its, output_prefix='/tmp/BB', total_sigma=0.5)
# lsyn1=antspyt1w.localsyn(img, img2, msk, msk2, whichHemi=1, padder=0, iterations=its, output_prefix='/tmp/CC', total_sigma=0.5)
